@@ -27,7 +27,7 @@ require Bio::Phylo::Mediators::TaxaMediator;
 # Include the revision number from subversion in $VERSION
 my $rev = '$Id: Phylo.pm 1660 2011-04-02 18:29:40Z rvos $';
 $rev =~ s/^[^\d]+(\d+)\b.*$/$1/;
-our $VERSION = "0.38";
+our $VERSION = "0.39";
 $VERSION .= "_$rev";
 {
     my $taxamediator = 'Bio::Phylo::Mediators::TaxaMediator';
@@ -64,6 +64,7 @@ $VERSION .= "_$rev";
     # like this as well.
     my @fields = \(
         my (
+	    %guid,
             %desc,
             %score,
             %generic,
@@ -235,6 +236,29 @@ argument "-name" in the constructor.
 
 =over
 
+=item set_guid()
+
+Sets invocant GUID.
+
+ Type    : Mutator
+ Title   : set_guid
+ Usage   : $obj->set_guid($guid);
+ Function: Assigns an object's GUID.
+ Returns : Modified object.
+ Args    : A scalar
+ Notes   : This field can be used for storing an identifier that is
+           unambiguous within a given content. For example, an LSID,
+	   a genbank accession number, etc.
+
+=cut
+
+    sub set_guid {
+        my ( $self, $guid ) = @_;
+        $guid{ $self->get_id } = $guid;
+        return $self;
+    }
+
+
 =item set_desc()
 
 Sets invocant description.
@@ -250,9 +274,6 @@ Sets invocant description.
 
     sub set_desc {
         my ( $self, $desc ) = @_;
-
-        # notify user
-        $logger->info("setting description '$desc'");
         $desc{ $self->get_id } = $desc;
         return $self;
     }
@@ -428,6 +449,27 @@ Gets invocant's 'fallback' name (possibly autogenerated).
         }
     }
 
+=item get_guid()
+
+Gets invocant GUID.
+
+ Type    : Accessor
+ Title   : get_guid
+ Usage   : my $guid = $obj->get_guid;
+ Function: Assigns an object's GUID.
+ Returns : Scalar.
+ Args    : None
+ Notes   : This field can be used for storing an identifier that is
+           unambiguous within a given content. For example, an LSID,
+	   a genbank accession number, etc.
+
+=cut
+
+    sub get_guid {
+	my $self = shift;
+	return $guid{ $self->get_id };
+    }
+
 =item get_desc()
 
 Gets invocant description.
@@ -443,7 +485,6 @@ Gets invocant description.
 
     sub get_desc {
         my $self = shift;
-        $logger->debug("getting description");
         return $desc{ $self->get_id };
     }
 
