@@ -2,8 +2,9 @@
 package Bio::Phylo::NeXML::Writable;
 use strict;
 use base 'Bio::Phylo';
-use Bio::Phylo::Util::Exceptions 'throw';
 use Bio::Phylo::NeXML::DOM;
+use Bio::Phylo::NeXML::Entities '/entities/';
+use Bio::Phylo::Util::Exceptions 'throw';
 use Bio::Phylo::Util::CONSTANT qw'/looks_like/ :namespaces :objecttypes';
 {
     my $logger              = __PACKAGE__->get_logger;
@@ -17,7 +18,7 @@ use Bio::Phylo::Util::CONSTANT qw'/looks_like/ :namespaces :objecttypes';
         'xsd' => _NS_XSD_,
     );
     my @fields =
-      \( my ( %tag, %id, %attributes, %identifiable, %suppress_ns, %meta ) );
+      \( my ( %tag, %id, %attributes, %identifiable, %suppress_ns, %meta, %url ) );
 
 =head1 NAME
 
@@ -270,9 +271,7 @@ Assigns attributes for the element.
             if ( $key =~ $fully_qualified_attribute_regex ) {
                 my ( $prefix, $attribute ) = ( $1, $2 );
                 if ( $prefix ne 'xmlns' and not exists $namespaces{$prefix} ) {
-                    $logger->warn(
-"Attribute '${prefix}:${attribute}' is not bound to a namespace"
-                    );
+                    $logger->warn("Unbound attribute prefix '${prefix}'");
                 }
             }
             $hash->{$key} = $attrs{$key};
@@ -300,6 +299,7 @@ the purpose of round-tripping nexml info sets.
         my ( $self, $id ) = @_;
         if ( $id =~ qr/^[a-zA-Z][a-zA-Z0-9\-_\.]*$/ ) {
             $id{ $self->get_id } = $id;
+            $self->set_attributes( 'id' => $id, 'about' => "#$id" );
             return $self;
         }
         else {
@@ -307,6 +307,49 @@ the purpose of round-tripping nexml info sets.
         }
     }
 
+=item set_base_uri()
+
+This utility method can be used to set the xml:base attribute, i.e. to specify
+a location for the object's XML serialization that potentially differs from
+the physical location of the containing document.
+
+ Type    : Mutator
+ Title   : set_base_uri
+ Usage   : $obj->set_base_uri('http://example.org');
+ Function: Sets the xml:base attribute
+ Returns : $self
+ Args    : A URI string
+
+=cut
+
+    sub set_base_uri {
+        my ( $self, $uri ) = @_;
+        $self->set_attributes( 'xml:base' => $uri );
+        return $self;
+    }
+
+=item set_link()
+
+This sets a clickable link, i.e. a url, for the object. This has no relation to
+the xml:base attribute, it is solely intended for serializations that
+allow clickable links, such as SVG or RSS.
+
+ Type    : Mutator
+ Title   : set_link
+ Usage   : $node->set_link($url);
+ Function: Sets clickable link
+ Returns : $self
+ Args    : url
+
+=cut
+
+    sub set_link {
+        my ( $self, $url ) = @_;
+        my $id = $self->get_id;
+        $url{$id} = $url;
+        return $self;
+    }
+
 =item unset_attribute()
 
 Removes specified attribute
@@ -375,14 +418,44 @@ Retrieves the metadata for the element.
 =cut
 
     sub get_meta {
-	my $self = shift;
-	my $metas = $meta{ $self->get_id } || [];
-        if ( @_ ) {
-	    my %predicates = map { $_ => 1 } @_;
-	    my @matches = grep { $predicates{$_->get_predicate} } @{ $metas };
-	    return \@matches;
-	}
-	return $metas;        
+		my $self = shift;
+		my $metas = $meta{ $self->get_id } || [];
+		if ( @_ ) {
+			my %predicates = map { $_ => 1 } @_;
+			my @matches = grep { $predicates{$_->get_predicate} } @{ $metas };
+			return \@matches;
+		}
+		return $metas;        
+    }
+
+=item get_meta_object()
+
+Retrieves the metadata annotation object for the provided predicate
+
+ Type    : Accessor
+ Title   : get_meta_object
+ Usage   : my $title = $obj->get_meta_object('dc:title');
+ Function: Retrieves the metadata annotation value for the object.
+ Returns : An annotation value, i.e. the object of a triple
+ Args    : Required: a CURIE predicate for which the annotation
+           value is returned
+ Note    : This method returns the object for the first annotation
+           with the provided predicate. Keep this in mind when dealing
+	   with an object that has multiple annotations with the same
+	   predicate.
+
+=cut
+    
+    sub get_meta_object {
+		my ( $self, $predicate ) = @_;
+		throw 'BadArgs' => "No CURIE provided" unless $predicate;
+		my ( $meta ) = @{ $self->get_meta($predicate) };
+		if ( $meta ) {
+			return $meta->get_object;
+		}
+		else {
+			return undef;
+		}
     }
 
 =item get_tag()
@@ -457,7 +530,7 @@ Retrieves tag string
         my $tag   = $self->get_tag;
         my $xml   = '<' . $tag;
         for my $key ( keys %attrs ) {
-            $xml .= ' ' . $key . '="' . $attrs{$key} . '"';
+            $xml .= ' ' . $key . '="' . encode_entities($attrs{$key}) . '"';
         }
         my $has_contents = 0;
         my $meta         = $self->get_meta;
@@ -489,19 +562,7 @@ Retrieves attributes for the element.
            can be found
 
 =cut
-    my $SAFE_CHARACTERS_REGEX = qr/(?:[a-zA-Z0-9]|-|_|\.)/;
-    my $XMLEntityEncode       = sub {
-        my $buf = '';
-        for my $c ( split //, shift ) {
-            if ( $c =~ $SAFE_CHARACTERS_REGEX ) {
-                $buf .= $c;
-            }
-            else {
-                $buf .= '&#' . ord($c) . ';';
-            }
-        }
-        return $buf;
-    };
+
     my $add_namespaces_to_attributes = sub {
         my ( $self, $attrs ) = @_;
         my $i                       = 0;
@@ -536,23 +597,29 @@ Retrieves attributes for the element.
     };
 
     sub get_attributes {
-        my $self  = shift;
+        my ( $self, $arg ) = @_;
         my $attrs = $flatten_attributes->($self);
-        if ( not exists $attrs->{'label'} and my $label = $self->get_name ) {
-            $attrs->{'label'} = $label;
-        }
-	if ( defined $attrs->{'label'} and $attrs->{'label'} ne '' ) {
-	    $attrs->{'label'} = $XMLEntityEncode->($attrs->{'label'});
-	}
-	else {
-	    delete $attrs->{'label'};
-	}
-        if ( not exists $attrs->{'id'} ) {
+	
+		# process the 'label' attribute: encode if there's anything there,
+		# otherwise delete the attribute
+		if ( $attrs->{'label'} ) {
+			$attrs->{'label'} = encode_entities($attrs->{'label'});
+		}
+		else {
+			delete $attrs->{'label'};
+		}
+	
+		# process the id attribute: if it's not there, autogenerate it, unless
+		# the object is explicitly not identifiable, in which case delete the
+		# attribute
+        if ( not $attrs->{'id'} ) {
             $attrs->{'id'} = $self->get_xml_id;
         }
         if ( defined $self->is_identifiable and not $self->is_identifiable ) {
             delete $attrs->{'id'};
         }
+	
+		# set the otus attribute
         if ( $self->can('get_taxa') ) {
             if ( my $taxa = $self->get_taxa ) {
                 $attrs->{'otus'} = $taxa->get_xml_id
@@ -563,23 +630,26 @@ Retrieves attributes for the element.
                   "$self can link to a taxa element, but doesn't";
             }
         }
+	
+		# set the otu attribute
         if ( $self->can('get_taxon') ) {
             if ( my $taxon = $self->get_taxon ) {
                 $attrs->{'otu'} = $taxon->get_xml_id;
             }
             else {
                 $logger->info("No linked taxon found");
+				delete $attrs->{'otu'};
             }
         }
-        $attrs = $add_namespaces_to_attributes->( $self, $attrs )
-          unless $self->is_ns_suppressed;
-        my $arg = shift;
-        if ($arg) {
-            return $attrs->{$arg};
-        }
-        else {
-            return $attrs;
-        }
+	
+		# add the namespace attributes unless explicitly supressed
+		if ( not $self->is_ns_suppressed ) {
+			$attrs = $add_namespaces_to_attributes->( $self, $attrs )
+		}
+		
+		# now either return the whole hash or just one value if a
+		# key/attribute name was provided
+		return $arg ? $attrs->{$arg} : $attrs;
     }
 
 =item get_xml_id()
@@ -602,12 +672,79 @@ Retrieves xml id for the element.
         }
         else {
             my $xml_id = $self->get_tag;
-	    my $obj_id = $self->get_id;
+			my $obj_id = $self->get_id;
             $xml_id =~ s/^(.).+(.)$/$1$2$obj_id/;
             return $id{$obj_id} = $xml_id;
         }
     }
 
+=item get_base_uri()
+
+This utility method can be used to get the xml:base attribute, which specifies
+a location for the object's XML serialization that potentially differs from
+the physical location of the containing document.
+
+If no xml:base attribute has been defined on the focal object, this method
+moves on, recursively, to containing objects (e.g. from node to tree to forest)
+until such time that a base URI has been found. 
+
+ Type    : Mutator
+ Title   : get_base_uri
+ Usage   : my $base = $obj->get_base_uri;
+ Function: Gets the xml:base attribute
+ Returns : A URI string
+ Args    : None
+
+=cut
+
+    sub get_base_uri {
+		my $self = shift;
+		while ( $self ) {
+			my $attrs = $flatten_attributes->($self);
+			if ( my $base = $attrs->{'xml:base'} ) {
+				$logger->info("Found xml:base attribute on $self: $base");
+				return $base;
+			}
+			
+			$logger->info("Traversing up to $self to locate xml:base");
+			# we do this because node objects are contained inside their
+			# parents, recursively, but node nexml elements aren't. it
+			# would be inefficient to traverse all the parent nodes when,
+			# logically, none of them could have an xml:base attribute
+			# that could apply to the original invocant. in fact, doing
+			# so could yield spurious results.
+			if ( $self->_type == _NODE_ ) {
+				$self = $self->get_tree;
+			}
+			else {
+				$self = $self->_get_container;
+			}	    
+		}
+		$logger->info("No xml:base attribute was found anywhere");
+		return undef;
+    }
+
+=item get_link()
+
+This returns a clickable link for the object. This has no relation to
+the xml:base attribute, it is solely intended for serializations that
+allow clickable links, such as SVG or RSS.
+
+ Type    : Accessor
+ Title   : get_link
+ Usage   : my $link = $obj->get_link();
+ Function: Returns a clickable link
+ Returns : url
+ Args    : NONE
+
+=cut
+
+    sub get_link {
+        my $self = shift;
+        my $id   = $self->get_id;
+        return $url{$id};
+    }
+
 =item get_dom_elt()
 
  Type    : Serializer
@@ -753,11 +890,10 @@ Serializes invocant to XML.
                     $xml .= "\n" . $ent->to_xml;
                 }
             }
-	    $xml .= $self->sets_to_xml;
+			$xml .= $self->sets_to_xml;
         }
         if ($xml) {
-            $xml =
-              $self->get_xml_tag . $xml . sprintf('</%s>', $self->get_tag);
+            $xml = $self->get_xml_tag . $xml . sprintf('</%s>', $self->get_tag);
         }
         else {
             $xml = $self->get_xml_tag(1);
